use v6.d;
use Test;
use FindBin::libs;

use ProcStats :Extract;

my %sample  = extract-stats;

diag 'Sample: ' ~ %sample.perl;

ok %sample, "Sample is populated.";

ok %sample{ $_ } :exists, "Sample has '$_'"
for |ProcStats::HEADER, |ProcStats::COMPARE;

done-testing;
